-- *****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5724-C40
-- * (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- *
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with
-- * IBM Corp.
-- *
-- *****************************************************************************


--------------------------------------------------------------------------
-- NOTE: this script uses the # character as statement terminator to allow
-- the use of a semicolonn into the body of the triggers and must then be
-- runned with the -td# switch of the DB2 CLP:
--
-- db2 -td# -vf amw_cdw_triggers.sql
--
--------------------------------------------------------------------------

--
-- the metric_id field for the AMW.stage_dm_metrics table is provided by an
-- ascending sequence AMW.metric_id_seq...
--
CREATE SEQUENCE AMW.metric_id_seq
  START WITH 1
  INCREMENT BY 1
  NO MAXVALUE
  NO CYCLE
  NO CACHE
  ORDER
#
-- ... and inserted in the AMW.stage_dm_metrics table by a before insert trigger
-- AMW.metric_id_trig.
--
CREATE TRIGGER AMW.metric_id_trig NO CASCADE
BEFORE INSERT ON AMW.stage_dm_metrics
REFERENCING NEW AS N
FOR EACH ROW
MODE DB2SQL
  SET N.metric_id = NEXTVAL FOR AMW.metric_id_seq
#
--
-- We provide also a trigger which tries to determine the Comp_Typ_Cd starting
-- from a given Comp_Nm and following this simple heuristic rule:
--
--   Comp_Typ_Cd = IP_HOST if there are two . in the Comp_Nm field
--   Comp_Typ_Cd = AMW_HOST otherwise
--
-- No further check is done to be sure that Comp_Typ_Cd really represent a
-- valid IP_HOST component type, but for DM this should just be guaranted by
-- the application itself.
-- The trigger also determines which kind of OS is running on the newly added
-- component looking for a proper substring in the Profile_Collection field
-- and inserting a dummy row into the TWG.Comp table in order to obtain the
-- following layout of records:
--
-- COMP_ID     COMPTYP_CD        COMP_NM                   COMP_DS
-- ----------- ----------------- ------------------------- ----------------------
-- 1           AMW_HOST          amwhost1                  NULL
-- 2           WIN_AMW_HOST      WIN_AMW_DATA              AMW_DATA
-- 3           AMW_HOST          amwhost2                  NULL
-- 4           UNIX_AMW_HOST     UNIX_AMW_DATA             AMW_DATA
-- 5           IP_HOST           iphost1.rome.tivoli.com   NULL
-- 6           WIN_IP_HOST       WIN_IP_DATA               AMW_DATA
-- 7           IP_HOST           iphost2.rome.tivoli.com   NULL
-- 8           UNIX_IP_HOST      UNIX_IP_DATA              AMW_DATA
--
-- It also keep track of the relationship between components and OS type information
-- inserting records into the TWG.CompReln table:
--
-- COMPRELN_ID COMP_SOURCE_ID COMP_TARGET_ID RELNTYP_CD
-- ----------- -------------- -------------- ----------
-- 1           1              2              PCHILD
-- 2           3              4              PCHILD
-- 3           5              6              PCHILD
-- 4           7              8              PCHILD
--
CREATE TRIGGER AMW.CompTyp_Cd_Trig
AFTER INSERT ON AMW.stage_comp
REFERENCING NEW AS N
FOR EACH ROW MODE DB2SQL
BEGIN ATOMIC
  IF LOCATE('.',N.Comp_Nm)>0 THEN
    IF LOCATE('.',N.Comp_Nm,LOCATE('.',N.Comp_Nm)+1)>0 THEN
      IF (SELECT COUNT(*) FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm) = 0 THEN
        insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values (N.Comp_ID, 'IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, N.Comp_Nm, N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, N.Comp_Ds);
        IF SUBSTR(N.Profile_Collection,5,2) = 'Nt' THEN
          insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values (N.Comp_ID, 'WIN_IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'WIN_IP_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
        ELSE
          insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values (N.Comp_ID, 'UNIX_IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'UNIX_IP_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
        END IF;
        insert into TWG.CompReln (COMPRELN_ID, COMP_SOURCE_ID, COMP_TARGET_ID, RELNTYP_CD, COMPRELN_STRT_DTTM, COMPRELN_END_DTTM) values(0, (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm), (SELECT MAX(Comp_ID) FROM TWG.Comp), 'PCHILD', N.Comp_Strt_DtTm, N.Comp_End_DtTm);
      ELSE
        IF (SELECT COUNT(*) FROM TWG.CompReln WHERE Comp_Source_ID = (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm) AND Comp_Target_ID IN ( SELECT Comp_ID FROM TWG.Comp WHERE Comp_Ds = 'AMW_DATA' )) = 0 THEN
          IF SUBSTR(N.Profile_Collection,5,2) = 'Nt' THEN
            insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values (N.Comp_ID, 'WIN_IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'WIN_IP_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
          ELSE
            insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values (N.Comp_ID, 'UNIX_IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'UNIX_IP_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
          END IF;
          insert into TWG.CompReln (COMPRELN_ID, COMP_SOURCE_ID, COMP_TARGET_ID, RELNTYP_CD, COMPRELN_STRT_DTTM, COMPRELN_END_DTTM) values(0, (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm), (SELECT MAX(Comp_ID) FROM TWG.Comp), 'PCHILD', N.Comp_Strt_DtTm, N.Comp_End_DtTm);
        END IF;
      END IF;
    ELSE
      IF (SELECT COUNT(*) FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm) = 0 THEN
        insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values (N.Comp_ID, 'AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, N.Comp_Nm, N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, N.Comp_Ds);
        IF SUBSTR(N.Profile_Collection,5,2) = 'Nt' THEN
          insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values (N.Comp_ID, 'WIN_AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'WIN_AMW_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
        ELSE
          insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values (N.Comp_ID, 'UNIX_AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'UNIX_AMW_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
        END IF;
        insert into TWG.CompReln (COMPRELN_ID, COMP_SOURCE_ID, COMP_TARGET_ID, RELNTYP_CD, COMPRELN_STRT_DTTM, COMPRELN_END_DTTM) values (0, (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm), (SELECT MAX(Comp_ID) FROM TWG.Comp), 'PCHILD', N.Comp_Strt_DtTm, N.Comp_End_DtTm);
      END IF;
    END IF;
  ELSE
    IF (SELECT COUNT(*) FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm) = 0 THEN
      insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values(N.Comp_ID, 'AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, N.Comp_Nm, N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, N.Comp_Ds);
      IF SUBSTR(N.Profile_Collection,5,2) = 'Nt' THEN
        insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values(N.Comp_ID, 'WIN_AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'WIN_AMW_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
      ELSE
        insert into TWG.Comp (COMP_ID, COMPTYP_CD, CENTR_CD, CUST_ID, COMP_CORR_ID, COMP_NM, COMP_CORR_VAL, COMP_STRT_DTTM, COMP_END_DTTM, COMP_DS) values(N.Comp_ID, 'UNIX_AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'UNIX_AMW_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
      END IF;
      insert into TWG.CompReln (COMPRELN_ID, COMP_SOURCE_ID, COMP_TARGET_ID, RELNTYP_CD, COMPRELN_STRT_DTTM, COMPRELN_END_DTTM) values (0, (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm), (SELECT MAX(Comp_ID) FROM TWG.Comp), 'PCHILD', N.Comp_Strt_DtTm, N.Comp_End_DtTm);
    END IF;
  END IF;
END
#

