-- *****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5724-C40
-- * (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- *
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with
-- * IBM Corp.
-- *
-- *****************************************************************************

-------------------------------------------------------------------------------------
----------------- BEGIN OF STATIC DATA SPECIFIC TO THE AMW APPLICATION --------------
-------------------------------------------------------------------------------------

--
-- //////////// Insert Component Types
--
declare global temporary table CompTyp (
       CompTyp_Cd           CHAR(17)     NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP    NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP    NOT NULL
)
with replace on commit preserve rows not logged
;
--
-- NOTE: Insert all time values in UTC format
--
-- //////////// The static data loaded into the CDW at initialization time must
-- //////////// include the following entry for the DM ETL process to work properly;
-- //////////// also the IP_HOST entry is required, but this is just inserted by the
-- //////////// twh_cdw_data.sql script
--

insert into session.CompTyp values ('APP_HOST',      NULL,       'Application Specific Hosts', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.CompTyp values ('AMW_HOST',      'APP_HOST', 'AMW Host',         current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.CompTyp values ('WIN_AMW_HOST',  'AMW_HOST', 'Windows AMW Host', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.CompTyp values ('UNIX_AMW_HOST', 'AMW_HOST', 'UNIX AMW Host',    current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.CompTyp values ('IP_HOST',       NULL,       'IP Host',         current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.CompTyp values ('WIN_IP_HOST',   'IP_HOST',  'Windows IP Host', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.CompTyp values ('UNIX_IP_HOST',  'IP_HOST',  'Unix IP Host',    current timestamp - current timezone, '9999-01-01-12.00.00.000000');


insert into TWG.CompTyp
select * from session.CompTyp s
where not exists (
  select 1 from
  TWG.CompTyp t where
  t.CompTyp_Cd = s.CompTyp_Cd
);

--
-- //////////// Insert Relationship Rules
-- //////////// (defines which type of components may participate in which types of relationships)
--

declare global temporary table RelnRul (
       CompTyp_Source_Cd  CHAR(17),
       CompTyp_Target_Cd  CHAR(17),
       RelnTyp_Cd         CHAR(6),
       RelnRul_Strt_DtTm  TIMESTAMP,
       RelnRul_End_DtTm   TIMESTAMP
)
with replace on commit preserve rows not logged
;

insert into session.RelnRul values(
  'AMW_HOST', 'UNIX_AMW_HOST', 'PCHILD', '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'
);
insert into session.RelnRul values(
  'IP_HOST',  'UNIX_IP_HOST',  'PCHILD', '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'
);
insert into session.RelnRul values(
  'AMW_HOST', 'WIN_AMW_HOST',  'PCHILD', '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'
);
insert into session.RelnRul values(
  'IP_HOST',  'WIN_IP_HOST',   'PCHILD', '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'
);
insert into session.RelnRul values(
  'APP_HOST', 'AMW_HOST',      'PCHILD', '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'
);

insert into TWG.RelnRul
select * from session.RelnRul s
where not exists (
  select 1 from
  TWG.RelnRul t where
  t.CompTyp_Source_Cd = s.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = s.CompTyp_Target_Cd and
  t.RelnTyp_Cd = s.RelnTyp_Cd and
  t.RelnRul_Strt_DtTm = s.RelnRul_Strt_DtTm
);

--
-- //////////// Insert Measurement Group Type codes
-- //////////// (a high level classification for a Measurement Group. Used to
-- //////////// distinguish between Mesurement Groups set up for different reasons)
--
declare global temporary table MGrpTyp (
  MGrpTyp_Cd           CHAR(6)      NOT NULL,
  MGrpTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MGrpTyp values ('DM2', 'CPU/MEM/NW/IO');

insert into TWG.MGrpTyp
select * from session.MGrpTyp s
where not exists (
  select 1 from
  TWG.MGrpTyp t where
  t.MGrpTyp_Cd = s.MGrpTyp_Cd
);

--
-- //////////// Insert Measurement Groups
--
declare global temporary table MGrp (
  MGrp_Cd              CHAR(6)      NOT NULL,
  MGrpTyp_Cd           CHAR(6)      NOT NULL,
  MGrp_Parent_Cd       CHAR(6),
  MGrp_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

-- we put the Monitors into CPU/MEM/NW/IO group (MGrpTyp_Cd=DM2)
insert into session.MGrp values ('CPU_E', 'DM2', NULL, 'CPU');
insert into session.MGrp values ('MEM_E', 'DM2', NULL, 'Memory');
insert into session.MGrp values ('NIC_E', 'DM2', NULL, 'Network interface');
insert into session.MGrp values ('HD_E',  'DM2', NULL, 'I/O');
insert into session.MGrp values ('FS_E',  'DM2', NULL, 'File system');

insert into TWG.MGrp
select * from session.MGrp s
where not exists (
  select 1 from
  TWG.MGrp t where
  t.MGrp_Cd    = s.MGrp_Cd and
  t.MGrpTyp_Cd = s.MGrpTyp_Cd
);

--
-- //////////// Insert Measurement Source Codes
-- //////////// (the MSrc_Cd field should match the three-letter product component
-- //////////// prefix required by the Tivoli Message Standard)
--
declare global temporary table MSrc (
  MSrc_Cd              CHAR(6)      NOT NULL,
  MSrc_Parent_Cd       CHAR(6),
  MSrc_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MSrc values ('AMW', 'Tivoli', 'IBM - Tivoli Monitoring 5.1');

insert into TWG.MSrc
select * from session.MSrc s
where not exists (
  select 1 from
  TWG.MSrc t where
  t.MSrc_Cd = s.MSrc_Cd
);

--
-- //////////// Insert Measurement Type (this is unique for each application)
-- //////////// (a type of mesurement that may be collected for a component, based
-- //////////// on its Component Type)
--
-- NOTE: the MsmtTyp_ID field is populated by the before insert trigger MsmtTyp_ID_Trig
--       so here we insert only a zero dummy value...
--
declare global temporary table MsmtTyp (
  MsmtTyp_ID           INTEGER      NOT NULL,
  MUnit_Cd             CHAR(6)      NOT NULL,
  MSrc_Cd              CHAR(6)      NOT NULL,
  MsmtTyp_Nm           VARCHAR(120) NOT NULL,
  MsmtTyp_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged
;

--
-- /////// CPU, UNIX
--
insert into session.MsmtTyp values ( 0, 'PRC', 'AMW', 'idleTime',
'CPU percent busy');
insert into session.MsmtTyp values ( 0, 'PRC', 'AMW',	'userTime',
'CPU percent user time');
insert into session.MsmtTyp values ( 0, 'PRC', 'AMW',	'sysTime',
'CPU percent system time');
insert into session.MsmtTyp values ( 0, 'QTY', 'AMW',	'loadAvg1',
'CPU run queue length');
insert into session.MsmtTyp values ( 0, 'QTY', 'AMW',	'numberWaitProcesses',
'Number of processes totally waiting');
insert into session.MsmtTyp values ( 0, 'QTY', 'AMW',	'numOfProcesses',
'Number of running processes');
--
-- /////// I/O, UNIX
--
insert into session.MsmtTyp values ( 0, 'KB',  'AMW', 'availKBytes',
'Disk Space available');
insert into session.MsmtTyp values ( 0, 'PRC', 'AMW',	'prcInodeUsed',
'Inode used in percent per file system');
--
-- /////// Memory, UNIX
--
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW',	'pageInsRate',
'Memory page-in rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW',	'pageOutsRate',
'Memory page-out rate');
insert into session.MsmtTyp values ( 0, 'MB',  'AMW', 'availSwapSpace',
'Swap space available');
insert into session.MsmtTyp values ( 0, 'PRC', 'AMW',	'pctusedVirtualStorage',
'Used virtual storage in percent');
--
-- /////// Network, UNIX
--
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW', 'deltaInPackets',
'Network packet input rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW',	'deltaInPacketsErr',
'Network packet input error rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW',	'deltaOutPackets',
'Network packet output rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW',	'deltaOutPacketsErr',
'Network packet output error rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW',	'deltaCollisions',
'Network packet collision rate');

--
-- /////// CPU, NT
--
insert into session.MsmtTyp values ( 0, 'QTY', 'AMW', 'NumberOfProcesses',
'Number of running processes');
--
-- NOTE: PrcTotCpuTime and PrcTotPrivTime monitors are common to both DMN
-- and AMW applications so thy must be inserted with a different
-- where-not-exists check...
--
insert into session.MsmtTyp values ( 0, 'PRC', 'AMW', 'PrcTotUserTime',
'CPU percent user time');
insert into session.MsmtTyp values ( 0, 'QTY', 'AMW', 'ProcessorQueueLength',
'CPU run queue length');
--
-- /////// Memory, NT
--
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW', 'PageInputSec',
'Memory page-in rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW', 'PageOutputSec',
'Memory page-out rate');
insert into session.MsmtTyp values ( 0, 'QTY', 'AMW', 'Avail',
'Memory available');
--
-- /////// Network, NT
--
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW', 'PacketsReceivedSec',
'Network packet input rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW', 'PacketsReceivedErrors',
'Network packet input error rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW', 'PacketsSentSec',
'Network packet output rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW', 'PacketsOutboundErrors',
'Network packet output error rate');
--
-- /////// I/O, NT
--
insert into session.MsmtTyp values ( 0, 'Bps', 'AMW', 'DiskBytesSec',
'Disk input / output rate');
insert into session.MsmtTyp values ( 0, 'Qps', 'AMW', 'DiskXfersSec',
'Disk transfer rate');
insert into session.MsmtTyp values ( 0, 'MB',  'AMW', 'FreeMB',
'Disk space available');

insert into TWG.MsmtTyp
select * from session.MsmtTyp s
where not exists (
  select 1 from
  TWG.MsmtTyp t where
  t.MsmtTyp_Nm = s.MsmtTyp_Nm
);

--
-- to allow the insertion of monitors with the same name for
-- both AMW and DMN applications, we need a further insertion
-- step with a where-not-exists check extended only to the
-- MsmtTyp_Nm field, because of the unique index defined on
-- this field at a CDW level. A more clean approach should be
-- to redefine the index in order to make unique the couple
-- of fields MSrc_Cd and MsmtTyp_Nm; in this way it's possible
-- to insert the 'PrcTotCpuTime' and 'PrcTotPrivTime' records
-- for both the DM applications:
--
--    MSrc_Cd  | MsmtTyp_Nm
--    ---------+---------------
--    DMN      | PrcTotCpuTime
--    DMN      | PrcTotPrivTime
--    AMW      | PrcTotCpuTime
--    AMW      | PrcTotPrivTime
--
declare global temporary table MsmtTyp (
  MsmtTyp_ID           INTEGER      NOT NULL,
  MUnit_Cd             CHAR(6)      NOT NULL,
  MSrc_Cd              CHAR(6)      NOT NULL,
  MsmtTyp_Nm           VARCHAR(120) NOT NULL,
  MsmtTyp_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged
;

insert into session.MsmtTyp values ( 0, 'PRC', 'AMW', 'PrcTotCpuTime',
'CPU percent busy');
insert into session.MsmtTyp values ( 0, 'PRC', 'AMW', 'PrcTotPrivTime',
'CPU percent system time');

insert into TWG.MsmtTyp
select * from session.MsmtTyp s
where not exists (
  select 1 from
  TWG.MsmtTyp t where
  t.MsmtTyp_Nm = s.MsmtTyp_Nm
);

--
-- //////////// Insert Measurement Group Member
-- //////////// (defines a type of measurement within a particular grouping
-- //////////// a Measurement Type may be a member of several Measurement Groups)
--
declare global temporary table MGrpMbr (
  MGrp_Cd              CHAR(6) NOT NULL,
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MsmtTyp_ID           INTEGER NOT NULL
)
with replace on commit preserve rows not logged
;

--
-- Probes/Monitors for which exists an Aggregate Type or Group Function
--

-- every AMW Monitor reports the Minimum value for the specific measure
insert into session.MGrpMbr
select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     'idleTime', 'userTime', 'sysTime', 'loadAvg1', 'numberWaitProcesses',
     'numOfProcesses', 'availKBytes', 'prcInodeUsed', 'pageInsRate', 'pageOutsRate',
     'availSwapSpace', 'pctusedVirtualStorage', 'deltaInPackets', 'deltaInPacketsErr',
     'deltaOutPackets', 'deltaOutPacketsErr', 'deltaCollisions',
     'NumberOfProcesses', 'PrcTotCpuTime', 'PrcTotUserTime', 'PrcTotPrivTime',
     'ProcessorQueueLength', 'PageInputSec', 'PageOutputSec', 'Avail',
     'PacketsReceivedSec', 'PacketsReceivedErrors', 'PacketsSentSec',
     'PacketsOutboundErrors', 'DiskBytesSec', 'DiskXfersSec', 'FreeMB' );

-- every AMW Monitor reports the Maximum value for the specific measure
insert into session.MGrpMbr
select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     'idleTime', 'userTime', 'sysTime', 'loadAvg1', 'numberWaitProcesses',
     'numOfProcesses', 'availKBytes', 'prcInodeUsed', 'pageInsRate', 'pageOutsRate',
     'availSwapSpace', 'pctusedVirtualStorage', 'deltaInPackets', 'deltaInPacketsErr',
     'deltaOutPackets', 'deltaOutPacketsErr', 'deltaCollisions',
     'NumberOfProcesses', 'PrcTotCpuTime', 'PrcTotUserTime', 'PrcTotPrivTime',
     'ProcessorQueueLength', 'PageInputSec', 'PageOutputSec', 'Avail',
     'PacketsReceivedSec', 'PacketsReceivedErrors', 'PacketsSentSec',
     'PacketsOutboundErrors', 'DiskBytesSec', 'DiskXfersSec', 'FreeMB' );

-- every AMW Monitor reports the Average value for the specific measure
insert into session.MGrpMbr
select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     'idleTime', 'userTime', 'sysTime', 'loadAvg1', 'numberWaitProcesses',
     'numOfProcesses', 'availKBytes', 'prcInodeUsed', 'pageInsRate', 'pageOutsRate',
     'availSwapSpace', 'pctusedVirtualStorage', 'deltaInPackets', 'deltaInPacketsErr',
     'deltaOutPackets', 'deltaOutPacketsErr', 'deltaCollisions',
     'NumberOfProcesses', 'PrcTotCpuTime', 'PrcTotUserTime', 'PrcTotPrivTime',
     'ProcessorQueueLength', 'PageInputSec', 'PageOutputSec', 'Avail',
     'PacketsReceivedSec', 'PacketsReceivedErrors', 'PacketsSentSec',
     'PacketsOutboundErrors', 'DiskBytesSec', 'DiskXfersSec', 'FreeMB' );

-- AMW Monitors doesn't report the Total value for the specific measure
insert into session.MGrpMbr
select 'TOT_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     '' );

--
-- Monitors for CPU/MEM/NW/IO belonging to the DM2 Measurement
-- Group Type (MGrpTyp_Cd=DM2)
--

-- CPU Monitors
insert into session.MGrpMbr
select 'CPU_E', 'DM2', mt.MsmtTyp_ID from twg.MsmtTyp mt where MsmtTyp_Nm in (
     'idleTime', 'userTime', 'sysTime', 'loadAvg1', 'numberWaitProcesses', 'numOfProcesses',
     'NumberOfProcesses', 'PrcTotCpuTime', 'PrcTotUserTime', 'PrcTotPrivTime', 'ProcessorQueueLength' );

-- Memory Monitors
insert into session.MGrpMbr
select 'MEM_E', 'DM2', mt.MsmtTyp_ID from twg.MsmtTyp mt where MsmtTyp_Nm in (
     'pageInsRate', 'pageOutsRate', 'availSwapSpace', 'pctusedVirtualStorage',
     'PageInputSec', 'PageOutputSec', 'Avail' );

-- Network Monitors
insert into session.MGrpMbr
select 'NIC_E', 'DM2', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     'deltaInPackets', 'deltaInPacketsErr', 'deltaOutPackets', 'deltaOutPacketsErr', 'deltaCollisions',
     'PacketsReceivedSec', 'PacketsReceivedErrors', 'PacketsSentSec', 'PacketsOutboundErrors' );

-- Hard Disk Drive Monitors
insert into session.MGrpMbr
select 'HD_E', 'DM2', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     'DiskBytesSec', 'DiskXfersSec' );

-- File System Monitors
insert into session.MGrpMbr
select 'FS_E', 'DM2', mt.MsmtTyp_ID from twg.MsmtTyp mt where MsmtTyp_Nm in (
     'availKBytes', 'prcInodeUsed', 'FreeMB' );

insert into TWG.MGrpMbr
select * from session.MGrpMbr s
where not exists (
  select 1 from
  TWG.MGrpMbr t where
  t.MGrp_Cd = s.MGrp_Cd and
  t.MGrpTyp_Cd = s.MGrpTyp_Cd and
  t.MsmtTyp_ID = s.MsmtTyp_ID
);

--
-- //////////// Insert Measurement Rule (this is unique for each application)
-- //////////// (which types of measurements are appropriate for which types
-- //////////// of components)
--
declare global temporary table MsmtRul (
  CompTyp_Cd      CHAR(17) NOT NULL,
  MsmtTyp_ID      INTEGER NOT NULL
)
with replace on commit preserve rows not logged
;

-- measurements appropriate for Windows hosts recognized as valid IP_HOST (15)
insert into session.MsmtRul
select 'WIN_IP_HOST', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     'NumberOfProcesses', 'PrcTotCpuTime', 'PrcTotUserTime', 'PrcTotPrivTime',
     'ProcessorQueueLength', 'PageInputSec', 'PageOutputSec', 'Avail',
     'PacketsReceivedSec', 'PacketsReceivedErrors', 'PacketsSentSec',
     'PacketsOutboundErrors', 'DiskBytesSec', 'DiskXfersSec', 'FreeMB' );


-- measurements appropriate for UNIX hosts recognized as valid IP_HOST (17)
insert into session.MsmtRul
select 'UNIX_IP_HOST', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     'idleTime', 'userTime', 'sysTime', 'loadAvg1', 'numberWaitProcesses', 'numOfProcesses',
     'availKBytes', 'prcInodeUsed', 'pageInsRate', 'pageOutsRate', 'availSwapSpace',
     'pctusedVirtualStorage', 'deltaInPackets', 'deltaInPacketsErr', 'deltaOutPackets',
     'deltaOutPacketsErr', 'deltaCollisions' );

-- NOTE: if it is not possible to identify a component as a valid IP_HOST (i.e.
-- if the Comp_Nm field of the TWH.Comp table doesn't contain a FQHN), the component
-- is trated as an AMW specific HOST, but we still need to apply the same rules
-- valid for components identifyed as IP_HOST so the following inserts basically
-- defines the same relationships of the previous three inserts.

-- measurements appropriate for Windows hosts not recognized as valid IP_HOST (15)
insert into session.MsmtRul
select 'WIN_AMW_HOST', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     'NumberOfProcesses', 'PrcTotCpuTime', 'PrcTotUserTime', 'PrcTotPrivTime',
     'ProcessorQueueLength', 'PageInputSec', 'PageOutputSec', 'Avail',
     'PacketsReceivedSec', 'PacketsReceivedErrors', 'PacketsSentSec',
     'PacketsOutboundErrors', 'DiskBytesSec', 'DiskXfersSec', 'FreeMB' );

-- measurements appropriate for UNIX hosts not recognized as valid IP_HOST (17)
insert into session.MsmtRul
select 'UNIX_AMW_HOST', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
     'idleTime', 'userTime', 'sysTime', 'loadAvg1', 'numberWaitProcesses', 'numOfProcesses',
     'availKBytes', 'prcInodeUsed', 'pageInsRate', 'pageOutsRate', 'availSwapSpace',
     'pctusedVirtualStorage', 'deltaInPackets', 'deltaInPacketsErr', 'deltaOutPackets',
     'deltaOutPacketsErr', 'deltaCollisions' );

insert into TWG.MsmtRul
select * from session.MsmtRul s
where not exists
( select 1 from
  TWG.MsmtRul t
  where
  t.MsmtTyp_ID = s.MsmtTyp_ID )
;

---------------------------------------------------------------------------------
--------------------------------- HELPER TABLES ---------------------------------
---------------------------------------------------------------------------------

--
-- //////////// Insert data into control table for pruning data from Msmt table.
-- //////////// A date duration is decimal(8,0) and has the format yyyymmdd.
--
declare global temporary table Prune_Msmt_Control(
       MSrc_Cd              CHAR(6) NOT NULL,
       TmSum_Cd             CHAR NOT NULL,
       PMsmtC_Age_In_Days   DECIMAL(8,0) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.Prune_Msmt_Control values (
  'AMW', 'H', 00000300
);
insert into session.Prune_Msmt_Control values (
  'AMW', 'D', 00000300
);
insert into session.Prune_Msmt_Control values (
  'AMW', 'W', 00010000
);
insert into session.Prune_Msmt_Control values (
  'AMW', 'M', 00010000
);

insert into TWG.Prune_Msmt_Control
select * from
 session.Prune_Msmt_Control s
where not exists
( select 1 from
  TWG.Prune_Msmt_Control t
  where
  t.MSrc_Cd  = s.MSrc_Cd and
  t.TmSum_Cd = s.TmSum_Cd)
;

--
-- The TWG extract control table has entries for all movement of data
-- when the CDW database is the source and the target table is
-- permanent (ie cannot be dropped and recreated if there is a failure)
--
declare global temporary table Extract_Control (
  ExtCtl_Source   	   varchar(120) not null,
  ExtCtl_Target   	   varchar(120) not null,
  ExtCtl_From_RawSeq   char(10) for bit data,
  ExtCtl_To_RawSeq     char(10) for bit data,
  ExtCtl_From_IntSeq   bigint,
  ExtCtl_To_IntSeq     bigint,
  ExtCtl_From_DtTm     timestamp not null,
  ExtCtl_To_DtTm       timestamp not null
  )
with replace on commit preserve rows not logged
;
--
-- ////////// We use extract control when moving data from RIM database to staging
--
-- we create the extract function for the ETL between the generic  RIM database
-- used by DM and the CDW database used by TWH; this ETL is  only an in-flow of
-- data from the DM_METRICS  table (really data  comes  from the  join  between
-- DM_METRICS and TWH_DM_METRICS tables) and a temporary  staging table that is
-- purged before any execution of the ETL process.
--
insert into session.Extract_Control values (
    'DM_METRICS' ,
    'AMW.STAGE_DM_METRICS' ,
    x'00000000000000000000',
    x'99999999999999999999',
    0,
    2000000000,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
--
-- ////////// Here we define an extract function to be used when initially importing
-- ////////// DM Data collected by a still not-patched version of DM.
--
insert into session.Extract_Control values (
    'DM_METRICS_INIT' ,
    'AMW.STAGE_DM_METRICS' ,
    x'00000000000000000000',
    x'99999999999999999999',
    0,
    2000000000,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
--
-- ////////// Use extract control when moving data from staging to TWG.MSMT
--
insert into session.Extract_Control values (
    'AMW.STAGE_METRICS_HOUR' ,
    'TWG.MSMT' ,
    x'00000000000000000000',
    x'99999999999999999999',
    0,
    2000000000,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

--
-- ////////// Extract Control functions used to buid the star schema
--
insert into session.Extract_Control values (
    'AMW.STAGE_D_METRIC' ,
    'AMW.D_DM2_METRIC' ,
    x'00000000000000000000',
    x'99999999999999999999',
    0,
    2000000000,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.Extract_Control values (
    'TWG.MSMT' ,
    'AMW.F_DAY' ,
    x'00000000000000000000',
    x'99999999999999999999',
    0,
    2000000000,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.Extract_Control values (
    'TWG.COMP' ,
    'AMW.D_HOST',
    x'00000000000000000000',
    x'99999999999999999999',
    0,
    2000000000,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
--
-- NOTE: Extract control is not needed when moving data from staging to TWG.Comp or
-- TWG.CompAttr because we use a where not exists when inserting data into these tables.
--
insert into TWG.Extract_control
select
 m.ExtCtl_Source as ExtCtl_Source,
 m.ExtCtl_Target as ExtCtl_Target,
 m.ExtCtl_From_RawSeq as ExtCtl_From_RawSeq,
 m.ExtCtl_To_RawSeq as ExtCtl_To_RawSeq,
 m.ExtCtl_From_IntSeq as ExtCtl_From_IntSeq,
 m.ExtCtl_To_IntSeq as ExtCtl_To_IntSeq,
 m.ExtCtl_From_DtTm as ExtCtl_From_DtTm,
 m.ExtCtl_To_DtTm as ExtCtl_To_DtTm
from
 session.Extract_Control m
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=m.ExtCtl_Source  and
  t.ExtCtl_Target=m.ExtCtl_Target
  )
;

--
-- //////////// Insert data into lookup tables to setup a single
-- //////////// customer/center environment.
--
insert into AMW.cust_lookup
values ('CDW', '@')
;

insert into AMW.centr_lookup
values ('CDW', '@')
;

--
-- //////////// insert static data into the DM metrics dimension staging tables
--
declare global temporary table temp_min_exists (
 msmttyp_id	    integer,
 min_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_min_exists
select
 mb.MsmtTyp_ID,
 'Y' as min_exists
from
 twg.MgrpMbr mb
where
 mb.MGrpTyp_Cd = 'GROUP' and
 mb.Mgrp_Cd = 'MIN_E'
;

select count(*) from session.temp_min_exists;

declare global temporary table temp_max_exists (
 MsmtTyp_ID	  integer,
 max_exists   char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_max_exists
select
 mb.MsmtTyp_ID,
 'Y' as max_exists
from
 twg.MGrpMbr mb
where
 mb.MGrpTyp_Cd = 'GROUP' and
 mb.MGrp_Cd='MAX_E'
;

select count(*) from session.temp_max_exists;

declare global temporary table temp_avg_exists (
 msmttyp_id	integer,
 avg_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 TWG.MgrpMbr mb
where
 mb.MGrpTyp_Cd = 'GROUP' and
 mb.MGrp_Cd='AVG_E'
;

select count(*) from session.temp_avg_exists;

declare global temporary table temp_tot_exists (
 msmttyp_id	integer,
 tot_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 TWG.MgrpMbr mb
where
 mb.MGrpTyp_Cd = 'GROUP' and
 mb.MGrp_Cd='TOT_E'
;

select count(*) from session.temp_tot_exists;

insert into AMW.stage_d_metric
select mt1.MsmtTyp_Id                as Metric_ID,
       current timestamp -
       current timezone              as Insert_DtTm,
       substr(mt1.MsmtTyp_Nm,1,30)   as Met_Name,
       mt1.MsmtTyp_Ds                as Met_Desc,
       mt1.MUnit_Cd                  as Met_Units ,
       mg.MGrp_Nm                    as Met_Category,
       value(min.min_exists,'N')     as Min_Exists,
       value(max.max_exists,'N')     as Max_Exists,
       value(avg.avg_exists,'N')     as Avg_Exists,
       value(tot.tot_exists,'N')     as Total_Exists,
       'IBM - Tivoli Monitoring 5.1' as MSrc_Nm
  from twg.MsmtTyp mt1 left outer join session.temp_min_exists min
       on mt1.MsmtTyp_ID = min.MsmtTyp_ID,
       twg.MsmtTyp mt2 left outer join session.temp_max_exists max
       on mt2.MsmtTyp_ID = max.MsmtTyp_ID,
       twg.MsmtTyp mt3 left outer join session.temp_avg_exists avg
       on mt3.MsmtTyp_ID = avg.MsmtTyp_ID,
       twg.MsmtTyp mt4 left outer join session.temp_tot_exists tot
       on mt4.MsmtTyp_ID = tot.MsmtTyp_ID,
       TWG.MsmtRul mr,
       TWG.Mgrp mg,
       TWG.MgrpMbr mgm
 where mt1.MsmtTyp_Id = mt2.MsmtTyp_ID and
       mt1.MsmtTyp_Id = mt3.MsmtTyp_ID and
       mt1.MsmtTyp_ID = mt4.MsmtTyp_ID and
       mt1.MsmtTyp_ID = mr.MsmtTyp_ID and
       mr.CompTyp_Cd in ('WIN_IP_HOST','UNIX_IP_HOST','WIN_AMW_HOST','UNIX_AMW_HOST') and
       (mt1.MSrc_Cd = 'AMW' or mt1.MSMTTYP_NM in ('PrcTotPrivTime','PrcTotCpuTime')) and
       mt1.MsmtTyp_ID = mgm.MsmtTyp_ID and
       mgm.MGrp_Cd = mg.MGrp_Cd and
       mgm.MGrpTyp_Cd = 'DM2'
group by
       mt1.MsmtTyp_ID, mt1.MsmtTyp_Nm, mt1.MsmtTyp_Ds, mt1.MUnit_Cd, mg.MGrp_Nm,
       min_exists, avg_exists, tot_exists, max_exists
;


