-- *****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5724-C40
-- * (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with
-- * IBM Corp.
-- *
-- *****************************************************************************

----------------------------------------------------------------------------
-- Here we perform a first Up-Flow of data from AMW.STAGE_DM_METRICS to the
-- staging table:
--
--   AMW.stage_metrics_hour_copy
--
-- Since this  happens  inside  the  same database  and  since we can always 
-- recreate from  scratch the  target tables (according  to the  appropriate 
-- templates), no extract control is required; the metric_id sequence number 
-- is also retrieved to enable the incremental  extract when  performing the 
-- final Up-Flow of data to the TWG.Msmt table.
----------------------------------------------------------------------------

--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table AMW.stage_metrics_hour_copy
;
--#EXECUTE_AT_TARGET
create table AMW.stage_metrics_hour_copy like AMW.stage_metrics_hour
;
--#EXECUTE_AT_TARGET
insert into AMW.stage_metrics_hour_copy
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '00:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '00:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_00 as Msmt_Min_Val,
 MAX_VALUE_00 as Msmt_Max_Val,
 AVG_VALUE_00 as Msmt_Avg_Val,
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '01:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '01:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_01 as Msmt_Min_Val, 
 MAX_VALUE_01 as Msmt_Max_Val, 
 AVG_VALUE_01 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '02:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '02:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_02 as Msmt_Min_Val, 
 MAX_VALUE_02 as Msmt_Max_Val, 
 AVG_VALUE_02 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '03:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '03:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_03 as Msmt_Min_Val, 
 MAX_VALUE_03 as Msmt_Max_Val, 
 AVG_VALUE_03 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union 
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '04:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '04:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_04 as Msmt_Min_Val, 
 MAX_VALUE_04 as Msmt_Max_Val, 
 AVG_VALUE_04 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '05:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '05:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_05 as Msmt_Min_Val, 
 MAX_VALUE_05 as Msmt_Max_Val, 
 AVG_VALUE_05 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
;

--#EXECUTE_AT_TARGET
insert into AMW.stage_metrics_hour_copy
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '06:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '06:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_06 as Msmt_Min_Val, 
 MAX_VALUE_06 as Msmt_Max_Val, 
 AVG_VALUE_06 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '07:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '07:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_07 as Msmt_Min_Val, 
 MAX_VALUE_07 as Msmt_Max_Val, 
 AVG_VALUE_07 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '08:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '08:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_08 as Msmt_Min_Val, 
 MAX_VALUE_08 as Msmt_Max_Val, 
 AVG_VALUE_08 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '09:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '09:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_09 as Msmt_Min_Val, 
 MAX_VALUE_09 as Msmt_Max_Val, 
 AVG_VALUE_09 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '10:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '10:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_10 as Msmt_Min_Val, 
 MAX_VALUE_10 as Msmt_Max_Val, 
 AVG_VALUE_10 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '11:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '11:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_11 as Msmt_Min_Val, 
 MAX_VALUE_11 as Msmt_Max_Val, 
 AVG_VALUE_11 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
;

--#EXECUTE_AT_TARGET
insert into AMW.stage_metrics_hour_copy
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '12:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '12:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_12 as Msmt_Min_Val, 
 MAX_VALUE_12 as Msmt_Max_Val, 
 AVG_VALUE_12 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '13:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '13:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_13 as Msmt_Min_Val, 
 MAX_VALUE_13 as Msmt_Max_Val, 
 AVG_VALUE_13 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union 
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '14:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '14:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_14 as Msmt_Min_Val, 
 MAX_VALUE_14 as Msmt_Max_Val, 
 AVG_VALUE_14 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '15:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '15:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_15 as Msmt_Min_Val, 
 MAX_VALUE_15 as Msmt_Max_Val, 
 AVG_VALUE_15 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union 
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '16:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '16:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_16 as Msmt_Min_Val, 
 MAX_VALUE_16 as Msmt_Max_Val, 
 AVG_VALUE_16 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union 
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '17:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '17:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_17 as Msmt_Min_Val, 
 MAX_VALUE_17 as Msmt_Max_Val, 
 AVG_VALUE_17 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
;

--#EXECUTE_AT_TARGET
insert into AMW.stage_metrics_hour_copy
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '18:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '18:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_18 as Msmt_Min_Val, 
 MAX_VALUE_18 as Msmt_Max_Val, 
 AVG_VALUE_18 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '19:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '19:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_19 as Msmt_Min_Val, 
 MAX_VALUE_19 as Msmt_Max_Val, 
 AVG_VALUE_19 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '20:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '20:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_20 as Msmt_Min_Val, 
 MAX_VALUE_20 as Msmt_Max_Val, 
 AVG_VALUE_20 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '21:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '21:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_21 as Msmt_Min_Val, 
 MAX_VALUE_21 as Msmt_Max_Val, 
 AVG_VALUE_21 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union 
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '22:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '22:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_22 as Msmt_Min_Val, 
 MAX_VALUE_22 as Msmt_Max_Val, 
 AVG_VALUE_22 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
union 
select
 metric_id, current timestamp - current timezone as insert_dttm,
 DATE(TIMESTAMP(COLLECTION_DATE, '23:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 TIME(TIMESTAMP(COLLECTION_DATE, '23:00:00') - TWH_GMTOFFSET_MIN MINUTE),
 lower(HOSTNAME), ENDPOINT, PROFILE_COLLECTION,
 PROBE_COLLECTION, PROBE, PROBE_DESC, PROBE_ARG,
 MIN_VALUE_23 as Msmt_Min_Val, 
 MAX_VALUE_23 as Msmt_Max_Val, 
 AVG_VALUE_23 as Msmt_Avg_Val, 
 0 as Msmt_Tot_Val, 0 as Msmt_Smpl_Cnt
from
 AMW.stage_dm_metrics
;

---------------------------------------------------------
-- now we populate the TWG Comp table for AMW application
---------------------------------------------------------

--
-- to determine the proper Comp_Typ_Cd we use the staging table AMW.stage_comp
-- and then we move all data to the TWG.Comp table; this furter step is required
-- in order to avoid any conflict with other ETLs that put data into the TWG.Comp
-- and may be influenced by a AMW.CompTyp_Cd_Trig acting directly on this table.
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table AMW.stage_comp
;
--#EXECUTE_AT_TARGET
create table AMW.stage_comp like TWG.Comp
;
-- we need an extended stage_comp table to pass also the information
-- used by the AMW.CompTyp_Cd_Trig to determine which OS is running on the
-- specific component.
ALTER TABLE AMW.stage_comp ADD COLUMN PROFILE_COLLECTION VARCHAR(64)
;
--
-- Dropping the table AMW.stage_comp makes inoperative the trigger responsible to 
-- determine the Comp_Typ_Cd. Issuing a CREATE TRIGGER statement with the same 
-- trigger-name as the inoperative trigger will cause that inoperative trigger 
-- to be replaced with a warning (SQLSTATE 01595), so also we need to instruct the 
-- execsql to IGNORE_ERROR.
-- NOTE: we need to override the default terminator ";" with the "$" sign because
-- the AMW.CompTyp_Cd_Trig has a body with statements are terminated by a ";"
--
--#EXECUTE_AT_TARGET
--#OVERRIDE_TERMINATOR $
--#IGNORE_ERROR
CREATE TRIGGER AMW.CompTyp_Cd_Trig
AFTER INSERT ON AMW.stage_comp
REFERENCING NEW AS N  
FOR EACH ROW MODE DB2SQL 
BEGIN ATOMIC
  IF LOCATE('.',N.Comp_Nm)>0 THEN 
    IF LOCATE('.',N.Comp_Nm,LOCATE('.',N.Comp_Nm)+1)>0 THEN
      IF (SELECT COUNT(*) FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm) = 0 THEN
        insert into TWG.Comp values(N.Comp_ID, 'IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, N.Comp_Nm, N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, N.Comp_Ds);
        IF SUBSTR(N.Profile_Collection,5,2) = 'Nt' THEN
          insert into TWG.Comp values(N.Comp_ID, 'WIN_IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'WIN_IP_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
        ELSE		
          insert into TWG.Comp values(N.Comp_ID, 'UNIX_IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'UNIX_IP_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
        END IF;		
        insert into TWG.CompReln values(0, (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm), (SELECT MAX(Comp_ID) FROM TWG.Comp), 'PCHILD', N.Comp_Strt_DtTm, N.Comp_End_DtTm);
      ELSE
        IF (SELECT COUNT(*) FROM TWG.CompReln WHERE Comp_Source_ID = (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm) AND Comp_Target_ID IN ( SELECT Comp_ID FROM TWG.Comp WHERE Comp_Ds = 'AMW_DATA' )) = 0 THEN
          IF SUBSTR(N.Profile_Collection,5,2) = 'Nt' THEN
            insert into TWG.Comp values(N.Comp_ID, 'WIN_IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'WIN_IP_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
          ELSE		
            insert into TWG.Comp values(N.Comp_ID, 'UNIX_IP_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'UNIX_IP_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
          END IF;		
          insert into TWG.CompReln values(0, (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm), (SELECT MAX(Comp_ID) FROM TWG.Comp), 'PCHILD', N.Comp_Strt_DtTm, N.Comp_End_DtTm);
        END IF;
      END IF;
    ELSE
      IF (SELECT COUNT(*) FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm) = 0 THEN
        insert into TWG.Comp values(N.Comp_ID, 'AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, N.Comp_Nm, N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, N.Comp_Ds);
        IF SUBSTR(N.Profile_Collection,5,2) = 'Nt' THEN
          insert into TWG.Comp values(N.Comp_ID, 'WIN_AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'WIN_AMW_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
        ELSE		
          insert into TWG.Comp values(N.Comp_ID, 'UNIX_AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'UNIX_AMW_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
        END IF;		
        insert into TWG.CompReln values(0, (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm), (SELECT MAX(Comp_ID) FROM TWG.Comp), 'PCHILD', N.Comp_Strt_DtTm, N.Comp_End_DtTm);
      END IF;
    END IF;
  ELSE
    IF (SELECT COUNT(*) FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm) = 0 THEN
      insert into TWG.Comp values(N.Comp_ID, 'AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, N.Comp_Nm, N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, N.Comp_Ds);
      IF SUBSTR(N.Profile_Collection,5,2) = 'Nt' THEN
        insert into TWG.Comp values(N.Comp_ID, 'WIN_AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'WIN_AMW_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
      ELSE		
        insert into TWG.Comp values(N.Comp_ID, 'UNIX_AMW_HOST', N.Centr_Cd, N.Cust_ID, N.Comp_Corr_ID, 'UNIX_AMW_DATA', N.Comp_Corr_Val, N.Comp_Strt_DtTm, N.Comp_End_DtTm, 'AMW_DATA');
      END IF;		
      insert into TWG.CompReln values(0, (SELECT Comp_ID FROM TWG.Comp WHERE Comp_Nm = N.Comp_Nm), (SELECT MAX(Comp_ID) FROM TWG.Comp), 'PCHILD', N.Comp_Strt_DtTm, N.Comp_End_DtTm);
    END IF;
  END IF;
END
$
--
-- we insert Comp records into the AMW.stage_comp table in order to let the AMW.CompTyp_Cd_Trig trigger
-- firing and putting the right records into the TWG.Comp and TWG.CompReln tables
--
--#EXECUTE_AT_TARGET
insert into AMW.stage_comp
select 
 0                      as Comp_ID,
 'IP_HOST'              as CompTyp_Cd,
 centr_lookup.Centr_Cd  as Centr_Cd,
 cust.Cust_ID           as Cust_ID,
 0                      as Comp_Corr_ID,
 d.Hostname             as Comp_Nm,
 ''                     as Comp_Corr_Val,	
 current timestamp - current timezone   as Comp_Strt_DtTm, 
 '9999-01-01-00.00.00.000000'           as Comp_End_DtTm,
 ''                     as Comp_Ds,
 d.PROFILE_COLLECTION   as PROFILE_COLLECTION
from
 AMW.stage_metrics_hour_copy d,
 AMW.cust_lookup  cust_lookup,
 AMW.centr_lookup centr_lookup,
 TWG.Cust cust
where
 ((cust_lookup.Value = d.Hostname AND cust_lookup.Cust_Acct_Cd = cust.Cust_Acct_Cd) 
   OR cust_lookup.Value = '@') AND
 (centr_lookup.Value = d.Hostname OR centr_lookup.Value = '@')
group by 
 d.Hostname, d.PROFILE_COLLECTION, centr_lookup.Centr_Cd, cust.Cust_ID
;

-------------------------------------------------------------
-- finally we populate the TWG Msmt table for AMW application
-------------------------------------------------------------

--
-- /////////////// open the extract window setting the high value for 
-- /////////////// the data to be extracted
--
--#EXECUTE_AT_TARGET
update TWG.Extract_Control 
  set extctl_to_intseq = (select max(metric_id) from AMW.stage_metrics_hour_copy),
      extctl_to_dttm = (select max(insert_dttm) from AMW.stage_metrics_hour_copy)
where 
  extctl_source='AMW.STAGE_METRICS_HOUR' and
  extctl_target='TWG.MSMT' and
  (select count(*) from AMW.stage_metrics_hour_copy) > 0
;
--
-- /////////////// start local data moving
-- 
-- /////////////// from: AMW.stage_metrics_hour_copy to: TWG.Msmt
--
--#EXECUTE_AT_TARGET
insert into TWG.Msmt ( Msmt_ID, Comp_ID, MsmtTyp_ID, TmSum_Cd, Msmt_Strt_Dt,
                       Msmt_Strt_Tm, Msmt_Min_Val, Msmt_Max_Val, Msmt_Avg_Val )
select
  0                    as Msmt_ID,
  os.Comp_ID           as Comp_ID,
  mtyp.MsmtTyp_ID      as MsmtTyp_ID,
  s.TmSum_Cd           as TmSum_Cd,
  d.Collection_Date    as Msmt_Strt_Dt,
  d.Collection_Time    as Msmt_Strt_Tm,
  avg(d.Msmt_Min_Val)  as Msmt_Min_Val,
  avg(d.Msmt_Max_Val)  as Msmt_Max_Val,
  avg(d.Msmt_Avg_Val)  as Msmt_Avg_Val 
from
  AMW.stage_metrics_hour_copy d,
  TWG.cur_comp comp,
  TWG.cur_comp os,
  TWG.CompReln cr,
  TWG.MsmtTyp mtyp,
  TWG.MsmtRul mrul,
  TWG.TmSum s,
  TWG.Extract_Control ec
where
  comp.Comp_Nm = d.Hostname and
  mtyp.MsmtTyp_Nm = d.Probe and 
  mtyp.MsmtTyp_ID = mrul.MsmtTyp_ID and
  (mrul.CompTyp_Cd IN ('WIN_IP_HOST','UNIX_IP_HOST','WIN_AMW_HOST','UNIX_AMW_HOST')) and
  s.TmSum_Nm = 'Hourly' and
  comp.Comp_ID = cr.Comp_Source_ID and 
  cr.Comp_Target_ID = os.Comp_ID and
  os.Comp_Ds = 'AMW_DATA'
group by
  os.Comp_ID,
  mtyp.MsmtTyp_ID,
  s.TmSum_Cd,
  d.collection_date,
  d.collection_time
;
--
-- /////////////// Confirm the insertion of data by inserting a row into TWG.EXTRACT_LOG.
-- /////////////// A trigger gets fired which updates the extract control table's from 
-- /////////////// data with the current to data.
--
--#EXECUTE_AT_TARGET
insert into TWG.Extract_Log
select
  ec.extctl_source      as extlog_source,
  ec.extctl_target      as extlog_target,
  current timestamp - current timezone as extlog_done_dttm,
  ec.extctl_from_rawseq as extlog_from_rawseq,
  ec.extctl_to_rawseq   as extlog_to_rawseq,
  ec.extctl_from_intseq as extlog_from_intseq,
  ec.extctl_to_intseq   as extlog_to_intseq,
  ec.extctl_from_dttm   as extlog_from_dttm,
  ec.extctl_to_dttm     as extlog_to_dttm
from 
  TWG.Extract_Control ec
where
  ec.extctl_source = 'AMW.STAGE_METRICS_HOUR' and
  ec.extctl_target = 'TWG.MSMT'
; 

