-- *****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5724-C40
-- * (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with
-- * IBM Corp.
-- *
-- *****************************************************************************

--
-- Here we perform an incremental extract using integer numbers to control
-- the extraction window; the source tables are the TWG schema tables located
-- at the CDW database (ODBC Src=twh_cdw); the target tables are dimension and
-- fact table located at the MART database (ODBC Tgt=twh_mart).
--

--
-- //////////// set the high value for the data to be extracted
--
update TWG.Extract_Control set 
 extctl_to_intseq = (select max(Metric_ID) from AMW.stage_d_metric),
 extctl_to_dttm = (select max(Insert_DtTm) from AMW.stage_d_metric)
where 
 extctl_source = 'AMW.STAGE_D_METRIC' and
 extctl_target = 'AMW.D_DM2_METRIC' and
 (select count(*) from AMW.stage_d_metric) > 0
;

--
-- //////////// fill the Metric Dimension Table with the static data retrieved at
-- //////////// initialization time and stored into the AMW.stage_d_metric table.
-- ////////////
-- //////////// NOTE: This process will only happen only once, because we initially  
-- ////////////       insert the data into the staging table in the cdw/dml script.
--
-- //////////// from: twh_cdw to: twh_mart
--
--#INSERT_INTO_TARGET
insert into AMW.D_DM2_METRIC
select 
  d.metric_id    as metric_id,
  d.met_name     as met_name,
  d.met_desc     as met_desc,
  d.met_units    as met_units,
  d.met_category as met_category,
  d.min_exists   as min_exists,
  d.max_exists   as max_exists,
  d.avg_exists   as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm      as msrc_nm
from
  AMW.stage_d_metric d,
  TWG.Extract_Control ec
where
  ec.extctl_source = 'AMW.STAGE_D_METRIC' and
  ec.extctl_target = 'AMW.D_DM2_METRIC' and
  d.metric_id > ec.extctl_from_intseq and
  d.metric_id <= ec.extctl_to_intseq 
;

--
-- //////////// Confirm the insertion of data by inserting a row into TWG.Extract_Log.
-- //////////// A trigger gets fired which updates the extract control table's from 
-- //////////// data with the current to data.
--
insert into TWG.Extract_Log
select
 ec.extctl_source      as extlog_source,
 ec.extctl_target      as extlog_target,
 current timestamp - 
 current timezone      as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq   as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq   as extlog_to_intseq,
 ec.extctl_from_dttm   as extlog_from_dttm,
 ec.extctl_to_dttm     as extlog_to_dttm
from 
 TWG.Extract_Control ec
where
 ec.extctl_source = 'AMW.STAGE_D_METRIC' and
 ec.extctl_target = 'AMW.D_DM2_METRIC'
;

--
-- //////////// fill the Fact Table with the data retrieved from TWG.Msmt table
--

--
-- //////////// set the high value for the data to be extracted
--
-- //////////// from: twh_cdw to: twh_mart
--
update TWG.Extract_Control set 
 extctl_to_intseq = (select max(msmt_id) from TWG.Msmt),
 extctl_to_dttm = (select max(timestamp(Msmt_Strt_Dt, Msmt_Strt_Tm)) from TWG.Msmt)
where 
 extctl_source = 'TWG.MSMT' and
 extctl_target = 'AMW.F_DAY' and
 (select count(*) from TWG.Msmt) > 0
;

--#INSERT_INTO_TARGET
insert into AMW.F_DAY
select m.Comp_ID                             as host_id, 
       m.MsmtTyp_Id                          as metric_id,
       timestamp(m.Msmt_Strt_Dt, '00.00.00') as meas_date,
       decimal(avg(m.Msmt_Min_Val),18,2)     as min_value,
       decimal(avg(m.Msmt_Max_Val),18,2)     as max_value,   
       decimal(avg(m.Msmt_Avg_Val),18,2)     as avg_value 		   
  from TWG.Msmt m, TWG.Comp c,
       TWG.Extract_Control ec 
 where m.Comp_ID = c.Comp_ID and
       ec.extctl_source = 'TWG.MSMT' and
       ec.extctl_target = 'AMW.F_DAY' and					
       m.Msmt_ID > ec.extctl_from_intseq and
       m.Msmt_ID <= ec.extctl_to_intseq
group by m.Msmt_Strt_Dt, m.Comp_ID, m.MsmtTyp_Id
;

--
-- //////////// Confirm the insertion of data by inserting a row into TWG.Extract_Log.
-- //////////// A trigger gets fired which updates the extract control table's from 
-- //////////// data with the current to data.
--
insert into TWG.Extract_Log
select
 ec.extctl_source      as extlog_source,
 ec.extctl_target      as extlog_target,
 current timestamp - 
 current timezone      as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq   as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq   as extlog_to_intseq,
 ec.extctl_from_dttm   as extlog_from_dttm,
 ec.extctl_to_dttm     as extlog_to_dttm
from 
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'AMW.F_DAY'
; 

--
-- //////////// fill the Component Dimension Table with the data retrieved from TWG.Comp table
--

--
-- //////////// set the high value for the data to be extracted
--
-- //////////// from: twh_cdw to: twh_mart
--
update TWG.Extract_Control set 
 extctl_to_intseq = (select max(Comp_ID) from TWG.Comp),
 extctl_to_dttm = (select max(Comp_Strt_DtTm) from TWG.Comp)
where 
 extctl_source = 'TWG.COMP' and
 extctl_target = 'AMW.D_HOST' and
 (select count(*) from TWG.Comp) > 0
;
--
-- //////////// we retrieve both the hostname of the component discovered by AMW and the 
-- //////////// information about the OS running on it
--
-- //////////// from: twh_cdw to: twh_mart
--
--#INSERT_INTO_TARGET
insert into AMW.D_HOST
select os.Comp_ID            as host_id,
       co.comp_strt_dttm     as host_start_dttm,
       co.comp_end_dttm      as host_end_dttm,
       co.Comp_Nm            as hostname,
       case
         when ct.CompTyp_Cd in ('UNIX_AMW_HOST','UNIX_IP_HOST') then 'Unix'
         when ct.CompTyp_Cd in ('WIN_AMW_HOST','WIN_IP_HOST') then 'Windows'
         else 'Unknown' 
       end                   as os_name,
       h.network_domain      as network_domain,    
       h.network_subdomain   as network_subdomain,    
       h.network_subdomain_2 as network_subdomain_2,    
       h.short_hostname	     as short_hostname
  from TWG.Comp co, 
       TWG.Comp os, 
       TWG.CompReln cr, 
       TWG.CompTyp ct,
       AMW.hostname_decomp h,
       TWG.Extract_Control ec
 where co.Comp_ID     = cr.Comp_Source_ID and
       os.Comp_ID     = cr.Comp_Target_ID and 
       os.CompTyp_Cd  = ct.CompTyp_Cd and
       os.Comp_Ds     = 'AMW_DATA' and
       co.Comp_ID     = h.host_id and
       ec.extctl_source = 'TWG.COMP' and
       ec.extctl_target = 'AMW.D_HOST' and					
       os.Comp_ID > ec.extctl_from_intseq and
       os.Comp_ID <= ec.extctl_to_intseq
;

--
-- //////////// Confirm the insertion of data by inserting a row into TWG.Extract_Log.
-- //////////// A trigger gets fired which updates the extract control table's from 
-- //////////// data with the current to data.
--
insert into TWG.Extract_Log
select
 ec.extctl_source      as extlog_source,
 ec.extctl_target      as extlog_target,
 current timestamp - 
 current timezone      as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq   as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq   as extlog_to_intseq,
 ec.extctl_from_dttm   as extlog_from_dttm,
 ec.extctl_to_dttm     as extlog_to_dttm
from 
 TWG.Extract_Control ec
where
 extctl_source = 'TWG.COMP' and
 extctl_target = 'AMW.D_HOST'
; 

