-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amx/pkg/v511/cdw/dml/amx_cdw_data.sql, tmnt_etl, tmnt_5.1.1_FP06, DM040219A
-- #  Revision: 1.3.1.2
-- #  Date: 1/27/04 12:02:41
-- ############################################################################

-----------------------------------------------------------------
-- Static data into the Prune table indicates that any data older 
-- than 10 days would be deleted in the source ITM database.
-- You can modify the first parameter if you want to change the 
-- age of the data that should be deleted in the source database
-----------------------------------------------------------------

declare global temporary table Prune_Control (
  age_days   integer,
  prune_key  integer 
)
with replace on commit preserve rows not logged
;

insert into session.Prune_Control values (10, 0);

insert into AMX.Prune_Control
select 
 m.age_days,
 m.prune_key
from 
 session.Prune_Control m
where not exists
(select 1 
   from AMX.prune_control t
);

-----------------------------------------------
-- /// Temporary Table for Extract Control ////
-----------------------------------------------

declare global temporary table Extract_Control (
  ExtCtl_Source         varchar(120) not null,
  ExtCtl_Target         varchar(120) not null,
  ExtCtl_From_RawSeq    char(10) for bit data,
  ExtCtl_To_RawSeq      char(10) for bit data,
  ExtCtl_From_IntSeq    bigint,
  ExtCtl_To_IntSeq      bigint,
  ExtCtl_From_DtTm     	timestamp not null,
  ExtCtl_To_DtTm       	timestamp not null
  )
with replace on commit preserve rows not logged
;

----------------------------------------------------
-- Tracing the AMX ETL1 PROCESS Start and End Dates
----------------------------------------------------

insert into session.extract_control values (
    'AMX_STATUS_ETL1_PROCESS' ,
    'AMX_STATUS_ETL1_PROCESS' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMX_STATUS_S005_PRE_EXTRACT_STEP' ,
    'AMX_STATUS_S005_PRE_EXTRACT_STEP' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMX_STATUS_S010_EXTRACT_STEP' ,
    'AMX_STATUS_S010_EXTRACT_STEP' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMX_STATUS_S020_PARSING_STEP' ,
    'AMX_STATUS_S020_PARSING_STEP' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMX_STATUS_S030_EXCEPTION_STEP' ,
    'AMX_STATUS_S030_EXCEPTION_STEP' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMX_STATUS_S040_COMP_MSMT_STEP' ,
    'AMX_STATUS_S040_COMP_MSMT_STEP' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into TWG.Extract_control
select 
 m.ExtCtl_Source as ExtCtl_Source,
 m.ExtCtl_Target as ExtCtl_Target,
 m.ExtCtl_From_RawSeq as ExtCtl_From_RawSeq,
 m.ExtCtl_To_RawSeq as ExtCtl_To_RawSeq,
 m.ExtCtl_From_IntSeq as ExtCtl_From_IntSeq,
 m.ExtCtl_To_IntSeq as ExtCtl_To_IntSeq,
 m.ExtCtl_From_DtTm as ExtCtl_From_DtTm,
 m.ExtCtl_To_DtTm as ExtCtl_To_DtTm  
from 
 session.Extract_Control m
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=m.ExtCtl_Source  and
  t.ExtCtl_Target=m.ExtCtl_Target
  )
; 

-----------
-- TWG.MSrc
-----------
--
-- Measurement Source Codes:
-- The monitoring tool that collected the measurements; the MSrc_Cd field should 
-- match the three-letter product component prefix required by the Tivoli Message 
-- Standard.
--
declare global temporary table MSrc (
  MSrc_Cd         CHAR(6) NOT NULL,
  MSrc_Parent_Cd  CHAR(6) NOT NULL,
  MSrc_Nm         VARCHAR(120) NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.MSrc values ('AMX', 'Tivoli', 'IBM Tivoli Monitoring'); 

insert into TWG.MSrc 
select 
 m.MSrc_Cd,
 m.MSrc_Parent_Cd,
 m.MSrc_Nm
from 
 session.MSrc m
where not exists
( select 1 from
  TWG.MSrc t
  where
  t.MSrc_Cd=m.MSrc_Cd )
; 

--------------
-- TWG.AttrTyp 
--------------
--
-- Attribute Types:
-- Defines the type of caractheristics or properties that may be captured about a component.
-- NOTE: AttrTyp_Cd is the primary key of the table
-- 
declare global temporary table AMX_AttrTyp (
  AttrTyp_Cd  CHAR(17) NOT NULL,
  AttrTyp_Nm  VARCHAR(120) NOT NULL
) 
with replace on commit preserve rows not logged
;

-- NOTE: The endpoints table contains 2 information that do not exist in the 
-- CDW by default, which are the endpoint id (EID) and the GMT offset (GMT_OFFSET). 
-- This requires two new attributes AMX_EID and AMX_GMT_OFFSET under the <AVA>_HOST.
insert into session.AMX_AttrTyp values ('AMX_EID', 'IBM Tivoli Monitoring Endpoint Identifier');
insert into session.AMX_AttrTyp values ('AMX_GMT_OFFSET', 'IBM Tivoli Monitoring Endpoint GMT Offset');  

insert into TWG.AttrTyp 
select 
 m.AttrTyp_Cd,
 m.AttrTyp_Nm
from 
 session.AMX_AttrTyp m
where not exists
( select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd=m.AttrTyp_Cd )
;
  
--
-- Insert data into lookup tables to setup a single customer/center 
-- environment: insert the Tivoli default customer_id and center code
--
insert into AMX.CUST_LOOKUP values ('DEF','@');

insert into AMX.CENTR_LOOKUP values ('CDW','@');


