#!/bin/sh
######################################################################
#
# Tivoli Enterprise Data Warehouse, v 1.1.0
# (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#   File Information: Common/src/tedw_app/amy/pkg/v110/misc/amy_after.sh, tmnt_etl, tmnt_5.1.1_FP06, DM040226G
#   Revision: 1.4
#   Date: 3/9/04 14:27:35
#######################################################################
#
# File Information: src/rpi/schema/app_after.sh, twh_rpi, twh_1.1_ode
#
# Revision: 1.4
#
# Date: 7/17/02 15:01:58
#
# Desc:  This is the template for WPack application after scripts.
#        It is intended to be used by WPack's that have additional
#        activities needed during the WPack installation, but that
#        there is no default logic in the WPack installer to handle.
#        There is a hook to execute a Core after script that is
#        required to allow dynamic patching of the WPack install
#        process.  Do not remove this hook.
#
#       NOTE - This after script only runs on the Control Server
#              and not on other distributed hosts.
#
# Command Line Args:
#       1 = the path and name of the TWH Application config file
#       2 = Application working directory or install base directory
#               $TWH_TOPDIR/apps/ava_code_for_app/vapp_version
#               (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this scirpt called
#       <ava>_after.sh.log
#
#
# Required Env Vars:
#       TWH_TOPDIR
#
# Return Codes (Only!):
#       0 = Success
#       255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#        * TWH Core tools components must be successfully installed
#
# Note - Caution needs to be taken for NT paths that have a space.
#        This is a limitation that requires double quoting around all
#        variables that contain a path.  Testing should be done to
#        ensure this script runs with a space in any of the paths
#        that are used.  For example "c:/program files".
#
######################################################################
#

echo "         ** After Script Log **         "
echo ""
echo "****************************************"
echo "* Application After Script Start point *"
echo "****************************************"

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Execute startup driver for afterscript
. "$TWH_TOPDIR"/install/bin/twh_core_startup_after.sh
exec_startup_driver;

create_new_patch_directory()
{
    echo "==> Adding Patch Directories"

    # Add a directory for marker files to be kept
    if [ ! -d "$TWH_TOPDIR"/apps/amy/.installed  ]; then
        mkdir -p "$TWH_TOPDIR"/apps/amy/.installed
        if [ $? -ne 0 ]; then
            echo "      (F) Failed to create the (.installed) directory"
            exit 81
        fi
        echo "      (I) Created .installed directory"
    else
        echo "      (I) .installed directory exists"
    fi
}

add_patch_v110600()
{
    
    echo "==> Adding Patch 1.1.0.600"
    
    # In a 1.2 environment, the TWH_RPI_HOST variable is still passed to 1.1 scripts, but since 
    # there is no RPI, the value is always set to RPI_NULL_HOST. We can indirectly check the TEDW 
    # version using this environment variable.
    if [ "x$TWH_RPI_HOST" != "xRPI_NULL_HOST" ]; then
        echo "      (I) You are installing on TEDW 1.1, creating patch 1.1.0.600 marker"
        if [ ! -f "$TWH_TOPDIR"/apps/amy/.installed ]
        then
            mkdir "$TWH_TOPDIR"/apps/amy/.installed
        fi         
        touch  "$TWH_TOPDIR"/apps/amy/.installed/.twh_amy_v1.1.0.600.marker
    else
        echo "      (I) You are installing on TDW 1.2, updating WEP version information"
        twh_setwepver AMY 1.1.0 1.1.0.600
    fi
    if [ $? -ne 0 ]; then
            echo "==> (F) Failed to add patch 1.1.0.600"
            echo "        Error is:"
            echo "        $err_txt"
            echo "        Exiting..."
            exit 255
    else
        echo "      (I) Patch 1.1.0.600 successfully added"
    fi
}


#####################################################
######## Add application code below here ONLY #######
#####################################################


################
# Main section #
################

echo "==> Processing main WPack routines"
echo ""

  create_new_patch_directory;
  add_patch_v110600;

echo "      (I) Done processing main WPack routines"
echo ""

#####################################
## Stop adding application code #####
#####################################

# as per the tedw_wpack_patchadm.sh documentation, the
# call to the exec_core_after function is no longer needed.
#exec_core_after;        # DO NOT MOVE OR REMOVE!

echo "==> Completed executing application after script"
exit 0

